<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>KWin::MultitaskViewEffect</name>
    <message>
        <source>Drag upwards to remove</source>
        <translation>Przeciągnij w górę, aby usunąć</translation>
    </message>
    <message>
        <source>No windows</source>
        <translation>Brak okien</translation>
    </message>
</context>
</TS>